//=============================================================================
// Change_TP_Custom.js
//   Last update: 2024/08/18
//=============================================================================
// 更新っぽいもの
// 
// 2024/08/18 [v0.1.0]
// 初版

/*:
 * @plugindesc
 * [v0.1.0] Change!! TP Custom.
 * 
 * @author Diamond
 *
 * @param TP Init Value
 * @text ????
 * @default 0
 * @desc
 * English is not supported.
 * Please Use Japanese!!
 * 
 * @param TP Carry Over
 * @text ????
 * @default 0
 * @desc
 * English is not supported.
 * Please Use Japanese!!
 * 
 * @help
 * Diamond use ruby, not use Java Script!!
 * Please use Ruby!! and RPG Tkool XP/VX/VX Ace.
 */

/*:ja
 * @plugindesc
 * [v0.1.0] 真（チェンジ！！）TP改
 * 
 * @author 貪藻矢射妥←
 * 
 * @param TP Init Value
 * @text TP初期値
 * @default 0
 * @desc
 * TP初期値を指定します。
 * 0 : 0始まり / 1以降 : 乱数始まり
 * 
 * @param TP Carry Over
 * @text TP持ち越し設定
 * @default 0
 * @desc
 * TP持ち越し設定を指定します。
 * 0 : Actorの能力依存 / 1 : 一律持ち越さず / 2 : 一律持ち越す
 *
 * @help
 * TPの設定についてカスタマイズします。
 * 
 * また、以下も対応
 * 戦闘不能時TPゲージがMaxになるのはおかしいのでは？と思い0に
 * TPを持ち越す場合、ステータス画面にTPゲージも表示
 *
 * Java ScriptよりもRubyを使いたい！ by 貪藻矢射妥←
 */

var OuterFlgs = OuterFlgs || {};

(function() {

OuterFlgs.imported = OuterFlgs.imported || {};
OuterFlgs.imported['TP_Custom'] = true;

var pluginParams = PluginManager.parameters('Change_TP_Custom');
var changeTPCustomInitValue = Number(pluginParams['TP Init Value'] || 0);
var changeTPCustomCarryOver = Number(pluginParams['TP Carry Over'] || 0);

Game_BattlerBase.TP_CARRY_OVER_AT_ACTOR    = 0;
Game_BattlerBase.TP_CARRY_OVER_IS_NONE     = 1;
Game_BattlerBase.TP_CARRY_OVER_IS_MUST     = 2;

//-----------------------------------------------------------------------------
// Game_Battler

Game_Battler.prototype.gainSilentTp = function(value) {
    if (!this.isDead()) {
        // アクターが死ななかった場合、TP増加(被ダメージ時)
        this.setTp(this.tp + value);
    } else {
        // アクターが死んだ場合、TPは0に戻す
        this.clearTp();
    }
};

Game_Battler.prototype.initTp = function() {
    if (changeTPCustomInitValue === 0) {
        // TPが0始まり固定
        this.setTp(0);
    } else {
        // TPの初期値を乱数で決定
        this.setTp(Math.randomInt(changeTPCustomInitValue));
    }
};

Game_Battler.prototype.onBattleStart = function() {
    this.setActionState('undecided');
    this.clearMotion();
    switch (changeTPCustomCarryOver){
    case Game_BattlerBase.TP_CARRY_OVER_AT_ACTOR:
        // アクターの能力如何でTP持ち越しを決める
        if (!this.isPreserveTp()) {
            this.initTp();
        }
        break;
    case Game_BattlerBase.TP_CARRY_OVER_IS_MUST:
        // 一律TPを持ち越す
        // TPの初期化を実施しない
        break;
    case Game_BattlerBase.TP_CARRY_OVER_IS_NONE:
    default:
        // 一律TPを持ち越さない
        this.initTp();
        break;
    }
};

Game_Battler.prototype.onBattleEnd = function() {
    this.clearResult();
    this.removeBattleStates();
    this.removeAllBuffs();
    this.clearActions();
    switch (changeTPCustomCarryOver){
    case Game_BattlerBase.TP_CARRY_OVER_AT_ACTOR:
        // アクターの能力如何でTP持ち越しを決める
        if (!this.isPreserveTp()) {
            this.clearTp();
        }
        break;
    case Game_BattlerBase.TP_CARRY_OVER_IS_MUST:
        // 一律TPを持ち越す
        // TPの初期化を実施しない
        break;
    case Game_BattlerBase.TP_CARRY_OVER_IS_NONE:
    default:
        // 一律TPを持ち越さない
        this.clearTp();
        break;
    }
    this.appear();
};

//-----------------------------------------------------------------------------
// Window_Status

Window_Status.prototype.drawBasicInfo = function(x, y) {
    var lineHeight = this.lineHeight();
    var tpDrawFlg = false;
    switch (changeTPCustomCarryOver){
    case Game_BattlerBase.TP_CARRY_OVER_AT_ACTOR:
        // アクターの能力如何でTPゲージ表示を決める
        if (this.isPreserveTp()) {
            tpDrawFlg = true;
        }
        break;
    case Game_BattlerBase.TP_CARRY_OVER_IS_MUST:
        // 一律TPゲージ表示
        tpDrawFlg = true;
        break;
    case Game_BattlerBase.TP_CARRY_OVER_IS_NONE:
    default:
        // 一律TPゲージを表示しない
        break;
    }
    
    var drawY = 0;
    if ( tpDrawFlg ){
        // TPゲージ表示の場合は表示位置を全体的にずらす
        drawY = -16;
    }
    
    this.drawActorLevel(this._actor, x, y + drawY + lineHeight * 0);
    this.drawActorIcons(this._actor, x, y + drawY + lineHeight * 1);
    this.drawActorHp(this._actor,    x, y + drawY + lineHeight * 2);
    this.drawActorMp(this._actor,    x, y + drawY + lineHeight * 3);
    if ( tpDrawFlg ){
        // TPゲージ表示が必要な場合
        this.drawActorTp(this._actor,    x, y + drawY + lineHeight * 4);
    }
};


})();
